# Copyright © 2021-2022 Arrikto Inc.  All Rights Reserved.

"""Kale SDK.

This script creates a pipeline that generates and adds 2 random integers and
prints the result.
"""

from random import randint

from kale import ContainerStep
from kale.sdk import step, pipeline


@step(name="gen_random_ints")
def random_ints():
    """Generate 2 random integers in the range [1,100]."""
    return randint(1, 100), randint(1, 100)


add = ContainerStep(
    name="add_random_ints",
    image="gcr.io/arrikto/example-add-split",
    command=["/bin/bash", "/add.sh"],
    args=["{{input.x}}", "{{input.y}}",
          "{{outfile.res}}"])


@step(name="print_result")
def print_result(x):
    """Print an input integer."""
    print("The result is: %d" % int(x))


@pipeline(name="add-random-ints",
          experiment="kale-tutorial")
def pipeline_func():
    """Run the ML pipeline."""
    a, b = random_ints()
    c = add(x=a, y=b)
    print_result(c)


if __name__ == "__main__":
    pipeline_func()
